You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hudi.apache.org by vi...@apache.org on 2021/02/09 18:34:06 UTC

[hudi] branch master updated: [MINOR] Fix the wrong comment for HoodieJavaWriteClientExample (#2559)

This is an automated email from the ASF dual-hosted git repository.

vinoth pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/hudi.git


The following commit(s) were added to refs/heads/master by this push:
     new a2f85d9  [MINOR] Fix the wrong comment for HoodieJavaWriteClientExample (#2559)
a2f85d9 is described below

commit a2f85d90de73a58e924b4de757d09d6133b046a4
Author: vinoyang <ya...@gmail.com>
AuthorDate: Wed Feb 10 02:33:34 2021 +0800

    [MINOR] Fix the wrong comment for HoodieJavaWriteClientExample (#2559)
---
 .../org/apache/hudi/examples/java/HoodieJavaWriteClientExample.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/hudi-examples/src/main/java/org/apache/hudi/examples/java/HoodieJavaWriteClientExample.java b/hudi-examples/src/main/java/org/apache/hudi/examples/java/HoodieJavaWriteClientExample.java
index 6cb1ea9..1ee5d1a 100644
--- a/hudi-examples/src/main/java/org/apache/hudi/examples/java/HoodieJavaWriteClientExample.java
+++ b/hudi-examples/src/main/java/org/apache/hudi/examples/java/HoodieJavaWriteClientExample.java
@@ -46,9 +46,9 @@ import java.util.stream.Collectors;
 /**
  * Simple examples of #{@link HoodieJavaWriteClient}.
  *
- * Usage: HoodieWriteClientExample <tablePath> <tableName>
+ * Usage: HoodieJavaWriteClientExample <tablePath> <tableName>
  * <tablePath> and <tableName> describe root path of hudi and table name
  * for example, `HoodieWriteClientExample file:///tmp/hoodie/sample-table hoodie_rt`
  */
 public class HoodieJavaWriteClientExample {
 
@@ -58,7 +58,7 @@ public class HoodieJavaWriteClientExample {
 
   public static void main(String[] args) throws Exception {
     if (args.length < 2) {
-      System.err.println("Usage: HoodieWriteClientExample <tablePath> <tableName>");
+      System.err.println("Usage: HoodieJavaWriteClientExample <tablePath> <tableName>");
       System.exit(1);
     }
     String tablePath = args[0];
@@ -46,9 +46,9 @@ import java.util.stream.Collectors;
  * <tablePath> and <tableName> describe root path of hudi and table name
- * for example, `HoodieWriteClientExample file:///tmp/hoodie/sample-table hoodie_rt`
+ * for example, `HoodieJavaWriteClientExample file:///tmp/hoodie/sample-table hoodie_rt`
  */
 public class HoodieJavaWriteClientExample {